@@ -123,17 +123,14 @@ use vars qw( %CONSTANTS );
     'CHAN_CLOSE_RCVD' => 0x02,
 
     'KEX_DH1' => 'diffie-hellman-group1-sha1',
-    'KEX_DH14_SHA1' => 'diffie-hellman-group14-sha1',
-    'KEX_DH14_SHA256' => 'diffie-hellman-group14-sha256',
-    'KEX_DH16_SHA512' => 'diffie-hellman-group16-sha512',
-    'KEX_DH18_SHA512' => 'diffie-hellman-group18-sha512',
+    'KEX_DH14' => 'diffie-hellman-group14-sha1',
     'KEX_DH_GEX_SHA256' => 'diffie-hellman-group-exchange-sha256',
     'KEX_DH_GEX_SHA1' => 'diffie-hellman-group-exchange-sha1',
     'KEX_CURVE25519_SHA256' => 'curve25519-sha256@libssh.org',
-    'KEX_DEFAULT_KEX' => 'curve25519-sha256@libssh.org,diffie-hellman-group16-sha512,diffie-hellman-group18-sha512,diffie-hellman-group-exchange-sha256,diffie-hellman-group14-sha256,diffie-hellman-group14-sha1',
-    'KEX_DEFAULT_PK_ALG' => 'ssh-ed25519,rsa-sha2-512,rsa-sha2-256,ecdsa-sha2-nistp521,ecdsa-sha2-nistp384,ecdsa-sha2-nistp256,ssh-rsa',
+    'KEX_DEFAULT_KEX' => 'curve25519-sha256@libssh.org,diffie-hellman-group-exchange-sha256,diffie-hellman-group-exchange-sha1,diffie-hellman-group14-sha1',
+    'KEX_DEFAULT_PK_ALG' => 'ssh-ed25519,rsa-sha2-512,rsa-sha2-256,ssh-rsa',
     'KEX_DEFAULT_ENCRYPT' => 'chacha20-poly1305@openssh.com,aes256-ctr,aes192-ctr,aes128-ctr',
-    'KEX_DEFAULT_MAC' => 'hmac-sha2-512-etm@openssh.com,hmac-sha2-256-etm@openssh.com,hmac-sha2-512,hmac-sha2-256',
+    'KEX_DEFAULT_MAC' => 'hmac-sha2-512-etm@openssh.com,hmac-sha2-256-etm@openssh.com,hmac-sha2-512,hmac-sha2-256,hmac-sha1',
     'KEX_DEFAULT_COMP' => 'none,zlib',
     'KEX_DEFAULT_LANG' => '',
 
