@@ -7,7 +7,7 @@ use warnings;
 use Crypt::PK::RSA;
 use Net::SSH::Perl::Buffer;
 use Net::SSH::Perl::Constants qw( SSH_COMPAT_BUG_RSASIGMD5 );
-use Crypt::Misc qw( encode_b64 );
+use MIME::Base64 qw( encode_base64 );
 use Carp qw( croak );
 use base qw( Net::SSH::Perl::Key );
 
@@ -36,7 +36,7 @@ sub init {
         my $ktype = $b->get_str;
         croak __PACKAGE__, "->init: cannot handle type '$ktype'"
             unless $ktype eq $key->ssh_name;
-        my $pubkey = $key->ssh_name . ' ' . encode_b64($blob);
+        my $pubkey = $key->ssh_name . ' ' . encode_base64($blob,'');
         $key->{rsa_pub}->import_key( \$pubkey );
     }
 
@@ -73,7 +73,7 @@ sub _pub_from_private {
     } );
 }
 
-sub size { eval { $_[0]->{rsa_pub}->size * 8 } }
+sub size { eval { $_[0]->{rsa_pub}->key2hash->{size} * 8 } }
 
 sub read_private {
     my $class = shift;
@@ -87,14 +87,16 @@ sub read_private {
 
 sub write_private {
     my $key = shift;
-    my($key_file, $passphrase, $cipher) = @_;
+    my($key_file, $passphrase) = @_;
 
-    my $pem = $key->{rsa_priv}->export_key_pem('private', $passphrase, $cipher) or return;
+    my $pem = $key->{rsa_priv}->export_key_pem('private', $passphrase) or return;
     open my $fh, '>', $key_file or croak "Can't write to $key_file: $!";
     print $fh $pem;
     close $fh or croak "Can't close $key_file: $!";
 }
 
+sub dump_public { $_[0]->ssh_name . ' ' . encode_base64( $_[0]->as_blob, '' ) }
+
 sub sign {
     my $key = shift;
     my($data) = @_;
@@ -141,8 +143,8 @@ sub as_blob {
     my $hash = defined $key->{rsa_pub} && $key->{rsa_pub}->key2hash;
     $b->put_str($key->ssh_name);
     my $e = substr('0',0,length($hash->{e}) % 2) . $hash->{e}; # prepend 0 if hex string is odd length, ie: 10001 (65537 decimal)
-    $b->put_mp_int(pack('H*',$e));
-    $b->put_mp_int(pack('H*',$hash->{N}));
+    $b->put_bignum2_bytes(pack('H*',$e));
+    $b->put_bignum2_bytes(pack('H*',$hash->{N}));
     $b->bytes;
 }
 
