@@ -10,6 +10,12 @@ use vars qw( %MAC %MAC_REVERSE %SUPPORTED );
 %MAC = (
     'hmac-sha1' => 'SHA1',
     'hmac-md5'  => 'MD5',
+    'hmac-sha2-256'  => 'SHA2_256',
+    'hmac-sha2-512'  => 'SHA2_512',
+    'hmac-sha2-256-etm@openssh.com'
+                     => 'SHA2_256',
+    'hmac-sha2-512-etm@openssh.com'
+                     => 'SHA2_512',
 );
 
 sub new {
@@ -18,6 +24,7 @@ sub new {
     my $mac_class = join '::', __PACKAGE__, $MAC{$type};
     my $mac = bless {}, $mac_class;
     $mac->init(@_) if @_;
+    $mac->{etm} = $type =~ /-etm\@openssh.com$/;
     $mac;
 }
 
@@ -36,33 +43,56 @@ sub key_len {
     $mac->{key_len} = shift if @_;
     $mac->{key_len};
 }
+sub etm { shift->{etm} }
 
 package Net::SSH::Perl::Mac::MD5;
 use strict;
-use Digest::HMAC_MD5 qw( hmac_md5 );
+use Crypt::Mac::HMAC;
 use vars qw( @ISA );
 @ISA = qw( Net::SSH::Perl::Mac );
 
 sub hmac {
-    my $mac = shift;
-    hmac_md5($_[0], $mac->{key});
+    Crypt::Mac::HMAC::hmac('MD5', shift->{key}, shift);
 }
 
 sub len { 16 }
 
 package Net::SSH::Perl::Mac::SHA1;
 use strict;
-use Digest::HMAC_SHA1 qw( hmac_sha1 );
+use Crypt::Mac::HMAC;
 use vars qw( @ISA );
 @ISA = qw( Net::SSH::Perl::Mac );
 
 sub hmac {
-    my $mac = shift;
-    hmac_sha1($_[0], $mac->{key});
+    Crypt::Mac::HMAC::hmac('SHA1', shift->{key}, shift);
 }
 
 sub len { 20 }
 
+package Net::SSH::Perl::Mac::SHA2_256;
+use strict;
+use Crypt::Mac::HMAC;
+use vars qw( @ISA );
+@ISA = qw( Net::SSH::Perl::Mac );
+
+sub hmac {
+    Crypt::Mac::HMAC::hmac('SHA256', shift->{key}, shift);
+}
+
+sub len { 32 }
+
+package Net::SSH::Perl::Mac::SHA2_512;
+use strict;
+use Crypt::Mac::HMAC;
+use vars qw( @ISA );
+@ISA = qw( Net::SSH::Perl::Mac );
+
+sub hmac {
+    Crypt::Mac::HMAC::hmac('SHA512', shift->{key}, shift);
+}
+
+sub len { 64 }
+
 1;
 __END__
 
@@ -149,4 +179,9 @@ or not to compute a MAC on an outgoing packet.
 Please see the Net::SSH::Perl manpage for author, copyright,
 and license information.
 
+hmac-sha2-256 and hmac-sha2-512 support added by:
+Lance Kinley E<lkinley@loyaltymethods.com>
+
+Copyright (c) 2015 Loyalty Methods, Inc.
+
 =cut
